@@ -13,7 +13,7 @@ BEGIN {
     require Time::Local;
 
     # Declare early to make sure Jifty::Record::schema_version works
-    $Jifty::VERSION = '0.90701';
+    $Jifty::VERSION = '0.91117';
 }
 
 =head1 NAME
@@ -250,8 +250,8 @@ sub new {
     my $app = Jifty->app_class;
     
     # Run the App::start() method if it exists for app-specific initialization
-    $app->start()
-        if $app->can('start');
+    $app->start
+        if not $args{no_handle} and $app->can('start');
 
     # For plugins that want all the above initialization, but want to run before
     # we begin serving requests
