@@ -227,10 +227,16 @@ sub current_user_has_timezone {
 
 =head2 set_current_user_timezone [DEFAULT_TZ]
 
+=head2 set_current_user_time_zone [DEFAULT_TZ]
+
 Set this Jifty::DateTime's timezone to the current user's timezone. If that's
 not available, then use the passed in DEFAULT_TZ (or GMT if not passed in).
 Returns the Jifty::DateTime object itself.
 
+If your subclass changes this method, please override
+C<set_current_user_timezone> not C<set_current_user_time_zone>, since the
+latter is merely an alias for the former.
+
 =cut
 
 sub set_current_user_timezone {
@@ -242,6 +248,8 @@ sub set_current_user_timezone {
     return $self;
 }
 
+sub set_current_user_time_zone { shift->set_current_user_timezone(@_) }
+
 =head2 new_from_string STRING[, ARGS]
 
 Take some user defined string like "tomorrow" and turn it into a
@@ -260,6 +268,7 @@ names. This may change in the future.
 sub new_from_string {
     my $class  = shift;
     my $string = shift;
+    return unless $string;
     my %args = (
         time_zone => undef,
         @_,
