@@ -6,7 +6,6 @@ use base 'Locale::Maketext';
 use Locale::Maketext::Lexicon ();
 use Email::MIME::ContentType;
 use Encode::Guess qw(iso-8859-1);
-use File::ShareDir 'module_dir';
 use Jifty::Util;
 
 =head1 NAME
@@ -26,7 +25,7 @@ In your Mason templates:
 
 =head2 C<_>
 
-This module provides a method named C<_>, which allows you to quickly and easily include localized strings in your application. The first argument is the string to translated. If that string contains placeholders, the remaining arguments are used to replace the placeholders. The placeholders in the form of "%1" where the number is the number of the argument used to replace it:
+This module provides a method named C<_>, which allows you to quickly and easily include localized strings in your application. The first argument is the string to be translated. If that string contains placeholders, the remaining arguments are used to replace the placeholders. The placeholders in the form of "%1" where the number is the number of the argument used to replace it:
 
   _('Welcome %1 to the %2', 'Bob', 'World');
 
@@ -71,11 +70,40 @@ sub new {
     my $lang = Jifty->config->framework('L10N')->{'Lang'};
     $lang = [defined $lang ? $lang : ()] unless ref($lang) eq 'ARRAY';
 
+    # Allow hard-coded allowed-languages in the config file
+    my $allowed_lang = Jifty->config->framework('L10N')->{'AllowedLang'};
+    $allowed_lang = [defined $allowed_lang ? $allowed_lang : ()] unless ref($allowed_lang) eq 'ARRAY';
+
+    if (@$allowed_lang) {
+        my $allowed_regex = join '|', map {
+            my $it = $_;
+            $it =~ tr<-A-Z><_a-z>; # lc, and turn - to _
+            $it =~ tr<_a-z0-9><>cd;  # remove all but a-z0-9_
+            $it;
+        } @$allowed_lang;
+
+        foreach my $lang ($self->available_languages) {
+            # "AllowedLang: zh" should let both zh_tw and zh_cn survive,
+            # so we just check ^ but not $.
+            $lang =~ /^$allowed_regex/ or delete $Jifty::I18N::{$lang.'::'};
+        }
+    }
+
     my $lh = $class->get_handle(@$lang);
 
     $DynamicLH = \$lh unless @$lang; 
     $self->init;
 
+    __PACKAGE__->install_global_loc($DynamicLH);
+    return $self;
+}
+
+=head2 install_global_loc
+
+=cut
+
+sub install_global_loc {
+    my ($class, $dlh) = @_;
     my $loc_method = sub {
         # Retain compatibility with people using "-e _" etc.
         return \*_ unless @_; # Needed for perl 5.8
@@ -88,7 +116,7 @@ sub new {
         # Force stringification to stop Locale::Maketext from choking on
         # things like DateTime objects.
         my @stringified_args = map {"$_"} @_;
-        my $result = eval { $lh->maketext(@stringified_args) };
+        my $result = eval { ${$dlh}->maketext(@stringified_args) };
         if ($@) {
             warn $@;
             # Sometimes Locale::Maketext fails to localize a string and throws
@@ -103,7 +131,16 @@ sub new {
         no warnings 'redefine';
         *_ = $loc_method;
     }
-    return $self;
+}
+
+=head2 available_languages
+
+Return an array of available languages
+
+=cut
+
+sub available_languages {
+    return map { /^(\w+)::/ ? $1 : () } sort keys %Jifty::I18N::;
 }
 
 =head2 _get_file_patterns
@@ -128,18 +165,40 @@ sub _get_file_patterns {
         push @ret, $dir ;
     }
 
+    # Unique-ify paths
+    my %seen;
+    @ret = grep {not $seen{$_}++} @ret;
+
     return ( map { $_ . '/*.po' } @ret );
 }
 
 =head2 get_language_handle
 
-Get the lanauge language for this request.
+Get the language handle for this request.
 
 =cut
 
 sub get_language_handle {
+    # XXX: subrequest should not need to get_handle again.
     my $self = shift;
-    $$DynamicLH = $self->get_handle() if $DynamicLH;
+    # optional argument makes it easy to disable I18N
+    # while comparing test strings (without loading session)
+    my $lang = shift || Jifty->web->session->get('jifty_lang');
+    $$DynamicLH = $self->get_handle($lang ? $lang : ()) if $DynamicLH;
+}
+
+=head2 get_current_language
+
+Get the current language for this request, formatted as a Locale::Maketext
+subclass string (i.e., C<zh_tw> instead of C<zh-TW>).
+
+=cut
+
+sub get_current_language {
+    return unless $DynamicLH;
+
+    my ($lang) = ref($$DynamicLH) =~ m/::(\w+)$/;
+    return $lang;
 }
 
 =head2 refresh
@@ -151,6 +210,18 @@ are modified on disk.
 
 my $LAST_MODIFED = '';
 sub refresh {
+    if ( Jifty->config->framework('L10N')->{'Disable'} && !$loaded) {
+        # skip loading po, but still do the translation for maketext
+        require Locale::Maketext::Lexicon;
+        my $lh = __PACKAGE__->get_handle;
+        my $orig = Jifty::I18N::en->can('maketext');
+        no warnings 'redefine';
+        *Jifty::I18N::en::maketext = Locale::Maketext::Lexicon->_style_gettext($orig);
+        __PACKAGE__->install_global_loc(\$lh);
+        ++$loaded;
+        return;
+    }
+
     my $modified = join(
         ',',
         #   sort map { $_ => -M $_ } map { glob("$_/*.po") } ( Jifty->config->framework('L10N')->{'PoDir'}, Jifty->config->framework('L10N')->{'DefaultPoDir'}
@@ -183,9 +254,15 @@ sub promote_encoding {
     my $class = shift;
     my $string = shift;
     my $content_type = shift;
+    my $charset;
 
-    $content_type = Email::MIME::ContentType::parse_content_type($content_type) if $content_type;
-    my $charset = $content_type->{attributes}->{charset} if $content_type;
+    # Don't bother parsing the Content-Type header unless it mentions "charset".
+    # This is to avoid the "Unquoted / not allowed in Content-Type" warnings when
+    # the Base64-encoded MIME boundary string contains "/".
+    if ($content_type and $content_type =~ /charset/i) {
+        $content_type = Email::MIME::ContentType::parse_content_type($content_type);
+        $charset = $content_type->{attributes}->{charset};
+    }
 
     # XXX TODO Is this the right thing? Maybe we should just return
     # the string as-is.
