@@ -67,7 +67,11 @@ template login_widget => sub {
         div {
             attr { id => 'jifty-login' };
             Jifty->web->form->start( call => $next );
-            render_param( $action, 'username', focus => 1 );
+            if ($action->login_by eq 'username' ) {
+                render_param( $action, 'username', focus => 1 );
+              } else {
+                render_param( $action, 'email', focus => 1 );
+              };
             render_param( $action, $_ ) for (qw(password remember));
             form_return( label => _(q{Login}), submit => $action );
             hyperlink(
