@@ -16,6 +16,8 @@ either a button or a link.
 
 use base 'Jifty::Web::Form::Element';
 
+=head1 METHODS
+
 =head2 accessors
 
 Clickable adds C<url>, C<escape_label>, C<continuation>, C<call>,
@@ -103,7 +105,7 @@ In the most complex case, you have something like this:
               ]
 
 If you specify arguments in the submit block for a button, they will override 
-any values from form fileds submitted by the user.
+any values from form fields submitted by the user.
 
 
 =item preserve_state
@@ -156,28 +158,30 @@ sub new {
     my ($root) = $ENV{'REQUEST_URI'} =~ /([^\?]*)/;
 
     my %args = (
-        parameters     => {},
-        as_button      => 0,
-        as_link        => 0,
+        parameters => {},
         @_,
     );
 
-    $class->call_trigger('before_new', \%args);
+    $class->call_trigger( 'before_new', \%args );
 
     $args{render_as_button} = delete $args{as_button};
     $args{render_as_link}   = delete $args{as_link};
 
-    my $self = $class->SUPER::new({
-        class          => '',
-        label          => 'Click me!',
-        url            => $root,
-        escape_label   => 1,
-        tooltip        => '',
-        continuation   => Jifty->web->request->continuation,
-        submit         => [],
-        preserve_state => 0,
-        parameters     => {},
-    }, \%args);
+    my $self = $class->SUPER::new(
+        {   class            => '',
+            label            => 'Click me!',
+            url              => $root,
+            escape_label     => 1,
+            tooltip          => '',
+            continuation     => Jifty->web->request->continuation,
+            submit           => [],
+            preserve_state   => 0,
+            parameters       => {},
+            render_as_button => 0,
+            render_as_link   => 0,
+            %args,
+        },
+    );
 
     for (qw/continuation call/) {
         $self->{$_} = $self->{$_}->id if $self->{$_} and ref $self->{$_};
@@ -194,7 +198,10 @@ sub new {
             if ( !ref($submit) ) { push @submit_temp, $submit }
 
             # We've been handed a Jifty::Action to submit
-            elsif ( blessed($submit) ) { push @submit_temp, $submit->moniker }
+            elsif ( blessed($submit) ) {
+                push @submit_temp, $submit->moniker;
+                $self->register_action($submit);
+            }
 
           # We've been handed a hashref which contains an action and arguments
             else {
@@ -206,18 +213,18 @@ sub new {
 
                 # Add the action's moniker to the submit
                 push @submit_temp, $submit->{'action'}->moniker;
+                $self->register_action($submit->{'action'});
             }
         }
 
         @{ $self->{submit} } = @submit_temp;
     }
 
-
     # Anything doing fragment replacement needs to preserve the
     # current state as well
-    if ( grep { $self->$_ } $self->handlers or $self->preserve_state ) {
+    if ( grep { $self->$_ } $self->handlers_used or $self->preserve_state ) {
         my %state_vars = Jifty->web->state_variables;
-        while ( my ($key,  $val) = each %state_vars ) {
+        while ( my ( $key, $val ) = each %state_vars ) {
             if ( $key =~ /^region-(.*?)\.(.*)$/ ) {
                 $self->region_argument( $1, $2 => $val );
             } elsif ( $key =~ /^region-(.*)$/ ) {
@@ -234,51 +241,48 @@ sub new {
     return $self;
 }
 
-=head2 url
+=head2 url [VALUE]
 
-Sets the page that the user will end up on after they click the
-button.  Defaults to the current page.
+Gets or sets the page that the user will end up on after they click
+the button.  Defaults to the current page.
 
-=head2 label
+=head2 label [VALUE]
 
-The text on the clickable object.
+Gets or sets the text on the clickable object.
 
-=head2 escape_label
+=head2 escape_label [VALUE]
 
-If set to true, HTML escapes the content of the label before
-displaying it.  This is only relevant for objects that are rendered as
-HTML links.  The default is true.
+Gets or sets if the label is escaped.  This is only relevant for
+objects that are rendered as HTML links.  The default is true.
 
-=head2 continuation
+=head2 continuation [VALUE]
 
-The current continuation for the link.  Defaults to the current
-continuation now, if there is one.  This may be either a
+Gets or sets the current continuation for the link.  Defaults to the
+current continuation now, if there is one.  This may be either a
 L<Jifty::Continuation> object, or the C<id> of such.
 
-=head2 call
+=head2 call [VALUE]
 
-The continuation to call when the link is clicked.  This will happen
-after actions have run, if any.  Like C<continuation>, this may be a
-L<Jifty::Continuation> object or the C<id> of such.
+Gets or sets the continuation to call when the link is clicked.  This
+will happen after actions have run, if any.  Like C<continuation>,
+this may be a L<Jifty::Continuation> object or the C<id> of such.
 
-=head2 returns
+=head2 returns [VALUE]
 
-Passing this parameter implies the creation of a continuation when the
-link is clicked.  It takes an anonymous hash of return location to
-where the return value is pulled from.  See L<Jifty::Request::Mapper>
-for details.
+Gets or sets the return value mapping from the continuation.  See
+L<Jifty::Request::Mapper> for details.
 
-=head2 submit
+=head2 submit [VALUE]
 
-A list of actions to run when the object is clicked.  This may be an
-array refrence or a single element; each element may either be a
-moniker or a L<Jifty::Action>.  An undefined value submits B<all>
-actions in the form, an empty list reference (the default) submits
-none.
+Gets or sets the list of actions to run when the object is clicked.
+This may be an array refrence or a single element; each element may
+either be a moniker or a L<Jifty::Action>.  An undefined value submits
+B<all> actions in the form, an empty list reference (the default)
+submits none.
 
-=head2 preserve_state
+=head2 preserve_state [VALUE]
 
-A boolean; whether state variables are preserved across the link.
+Gets or sets whether state variables are preserved across the link.
 Defaults to true if there are any AJAX actions on the link, false
 otherwise.
 
@@ -302,8 +306,8 @@ Sets the state variable named C<KEY> to C<VALUE>.
 
 sub state_variable {
     my $self = shift;
-    defined $self->call_trigger('before_state_variable', @_)
-        or return; # if aborted by trigger
+    defined $self->call_trigger( 'before_state_variable', @_ )
+        or return;    # if aborted by trigger
 
     my ( $key, $value, $fallback ) = @_;
     if ( defined $value and length $value ) {
@@ -345,9 +349,9 @@ sub region_argument {
     my $self = shift;
     my ( $region, $argument, $value ) = @_;
 
-    my $name = ref $region ? $region->qualified_name : $region;
+    my $name     = ref $region ? $region->qualified_name : $region;
     my $defaults = Jifty->web->get_region($name);
-    my $default = $defaults ? $defaults->default_argument($argument) : undef;
+    my $default  = $defaults ? $defaults->default_argument($argument) : undef;
 
     if (   ( not defined $default and not defined $value )
         or ( defined $default and defined $value and $default eq $value ) )
@@ -364,8 +368,9 @@ sub _map {
     my %old_args = @_;
     my %new_args;
 
-    while (my ($key, $val) = each %old_args) {
-        my ($new_key, $new_val) = Jifty::Request::Mapper->query_parameters($key => $val);
+    while ( my ( $key, $val ) = each %old_args ) {
+        my ( $new_key, $new_val )
+            = Jifty::Request::Mapper->query_parameters( $key => $val );
         $new_args{$new_key} = $new_val;
     }
 
@@ -386,17 +391,19 @@ sub parameters {
     my %parameters;
 
     if ( $self->returns ) {
-        %parameters = Jifty::Request::Mapper->query_parameters( %{ $self->returns } );
+        %parameters
+            = Jifty::Request::Mapper->query_parameters( %{ $self->returns } );
         $parameters{"J:CREATE"} = 1;
-        $parameters{"J:PATH"} = Jifty::Web::Form::Clickable->new( url => $self->url,
-                                                                  parameters => $self->{parameters},
-                                                                  continuation => undef,
-                                                                )->complete_url;
+        $parameters{"J:PATH"}   = Jifty::Web::Form::Clickable->new(
+            url          => $self->url,
+            parameters   => $self->{parameters},
+            continuation => undef,
+        )->complete_url;
     } else {
-        %parameters = %{ $self->{parameters} };        
+        %parameters = %{ $self->{parameters} };
     }
 
-    %parameters = _map( %{$self->{state_variable} || {}}, %parameters );
+    %parameters = _map( %{ $self->{state_variable} || {} }, %parameters );
 
     $parameters{"J:CALL"} = $self->call
         if $self->call;
@@ -410,20 +417,23 @@ sub parameters {
 
 =head2 post_parameters
 
-The hash of parameters as they would be needed on a POST request.
+Returns the hash of parameters as they would be needed on a POST
+request.
 
 =cut
 
 sub post_parameters {
     my $self = shift;
 
-    my %parameters = ( _map( %{ $self->{fallback} || {} } ), $self->parameters );
+    my %parameters
+        = ( _map( %{ $self->{fallback} || {} } ), $self->parameters );
 
     my ($root) = $ENV{'REQUEST_URI'} =~ /([^\?]*)/;
 
     # Submit actions should only show up once
     my %uniq;
-    $self->submit([grep {not $uniq{$_}++} @{$self->submit}]) if $self->submit;
+    $self->submit( [ grep { not $uniq{$_}++ } @{ $self->submit } ] )
+        if $self->submit;
 
     # Add a redirect, if this isn't to the right page
     if ( $self->url ne $root and not $self->returns ) {
@@ -432,11 +442,12 @@ sub post_parameters {
             arguments => { url => $self->url } );
         $parameters{ $redirect->register_name } = ref $redirect;
         $parameters{ $redirect->form_field_name('url') } = $self->url;
-        $parameters{"J:ACTIONS"} = join( '!', @{ $self->submit }, $redirect->moniker )
-          if $self->submit;
+        $parameters{"J:ACTIONS"}
+            = join( '!', @{ $self->submit }, $redirect->moniker )
+            if $self->submit;
     } else {
         $parameters{"J:ACTIONS"} = join( '!', @{ $self->submit } )
-          if $self->submit;
+            if $self->submit;
     }
 
     return %parameters;
@@ -444,7 +455,8 @@ sub post_parameters {
 
 =head2 get_parameters
 
-The hash of parameters as they would be needed on a GET request.
+Returns the hash of parameters as they would be needed on a GET
+request.
 
 =cut
 
@@ -479,8 +491,9 @@ sub complete_url {
 
 sub _defined_accessor_values {
     my $self = shift;
-    return { map { my $val = $self->$_; defined $val ? ($_ => $val) : () } 
-        $self->SUPER::accessors };
+    # Note we're walking around Class::Accessor here
+    return { map { my $val = $self->{"_$_"} || $self->{$_}; defined $val ? ( $_ => $val ) : () }
+            $self->SUPER::accessors };
 }
 
 =head2 as_link
@@ -496,24 +509,26 @@ sub as_link {
 
     my $args = $self->_defined_accessor_values;
     my $link = Jifty::Web::Form::Link->new(
-        { %$args,
-          escape_label => $self->escape_label,
-          url          => $self->complete_url,
-          target       => $self->target,
-          continuation => $self->_continuation,
-          @_ }
+        {   %$args,
+            escape_label => $self->escape_label,
+            url          => $self->complete_url,
+            target       => $self->target,
+            continuation => $self->_continuation,
+            @_
+        }
     );
     return $link;
 }
 
 sub _continuation {
+
     # continuation info used by the update() call on client side
     my $self = shift;
-    if ($self->call) {
-	return { 'type' => 'call', id => $self->call };
+    if ( $self->call ) {
+        return { 'type' => 'call', id => $self->call };
     }
-    if ($self->returns) {
-	return { 'create' => $self->url };
+    if ( $self->returns ) {
+        return { 'create' => $self->url };
     }
 
     return {};
@@ -531,12 +546,14 @@ appropriate.
 sub as_button {
     my $self = shift;
 
-    my $args = $self->_defined_accessor_values;
+    my $args  = $self->_defined_accessor_values;
     my $field = Jifty::Web::Form::Field->new(
-        { %$args,
-          type => 'InlineButton',
-          continuation => $self->_continuation,
-          @_ }
+        {   %$args,
+            type         => 'InlineButton',
+            continuation => $self->_continuation,
+            title        => $self->tooltip,
+            @_
+        }
     );
     my %parameters = $self->post_parameters;
 
@@ -546,7 +563,7 @@ sub as_button {
             grep { defined $parameters{$_} } keys %parameters
     );
     $field->name( join '|', keys %{ $args->{parameters} } );
-    $field->button_as_link($self->render_as_link);
+    $field->button_as_link( $self->render_as_link );
 
     return $field;
 }
@@ -565,45 +582,88 @@ parameters.
 
 sub generate {
     my $self = shift;
-    for my $trigger ( $self->handlers ) {
+    my $web = Jifty->web;
+    for my $trigger ( $self->handlers_used ) {
         my $value = $self->$trigger;
         next unless $value;
         my @hooks = @{$value};
         for my $hook (@hooks) {
             next unless ref $hook eq "HASH";
-            $hook->{region} ||= $hook->{refresh} || Jifty->web->qualified_region;
+            $hook->{region} ||= $hook->{refresh}
+                || $web->qualified_region;
 
-            my $region = ref $hook->{region} ? $hook->{region} : Jifty->web->get_region( $hook->{region} );
+            my $region
+                = ref $hook->{region}
+                ? $hook->{region}
+                : $web->get_region( $hook->{region} );
 
-            if ($hook->{replace_with}) {
+            if ( $hook->{replace_with} ) {
                 my $currently_shown = '';
                 if ($region) {
 
-                my $state_var = Jifty->web->request->state_variable("region-".$region->qualified_name);
-                $currently_shown = $state_var->value if ($state_var);
-                } 
-                # Toggle region if the toggle flag is set, and clicking wouldn't change path
-                if ($hook->{toggle} and $hook->{replace_with} eq $currently_shown) {
-                    $self->region_fragment( $hook->{region}, "/__jifty/empty" );
-#                    Jifty->web->request->remove_state_variable('region-'.$region->qualified_name);
-                } else {
-                    $self->region_fragment( $hook->{region}, $hook->{replace_with} )
+                    my $state_var = $web->request->state_variable(
+                        "region-" . $region->qualified_name );
+                    $currently_shown = $state_var->value if ($state_var);
                 }
-                
+
+  # Toggle region if the toggle flag is set, and clicking wouldn't change path
+                if (    $hook->{toggle}
+                    and $hook->{replace_with} eq $currently_shown )
+                {
+                    $self->region_fragment( $hook->{region},
+                        "/__jifty/empty" );
+
+                } else {
+                    $self->region_fragment( $hook->{region},
+                        $hook->{replace_with} );
+                }
+
             }
             $self->region_argument( $hook->{region}, $_ => $hook->{args}{$_} )
                 for keys %{ $hook->{args} };
             if ( $hook->{submit} ) {
                 $self->{submit} ||= [];
-                $hook->{submit} = [ $hook->{submit} ] unless ref $hook->{submit} eq "ARRAY";
+                for my $moniker ( @{ $hook->{submit} } ) {
+                    my $action = $web->{'actions'}{$moniker};
+                    $self->register_action($action);
+                    $self->parameter( $action->form_field_name($_),
+                        $hook->{action_arguments}{$moniker}{$_} )
+                        for
+                        keys %{ $hook->{action_arguments}{$moniker} || {} };
+                }
                 push @{ $self->{submit} }, @{ $hook->{submit} };
             }
         }
     }
 
-    return ( ( not( $self->submit ) || @{ $self->submit } || $self->render_as_button )
+    return (
+        (          not( $self->submit )
+                || @{ $self->submit }
+                || $self->render_as_button
+        )
         ? $self->as_button(@_)
-        : $self->as_link(@_) );
+        : $self->as_link(@_)
+    );
+}
+
+=head2 register_action ACTION
+
+Reisters the action if it isn't registered already, but only on the
+link.  That is, the registration will not be seen by any other buttons
+in the form.
+
+=cut
+
+sub register_action {
+    my $self = shift;
+    my ($action) = @_;
+    return if Jifty->web->form->actions->{ $action->moniker };
+
+    my $arguments = $action->arguments;
+    $self->parameter( $action->register_name, ref $action );
+    $self->parameter( $action->fallback_form_field_name($_),
+        $action->argument_value($_) || $arguments->{$_}->{'default_value'} )
+        for grep { $arguments->{$_}{constructor} } keys %{$arguments};
 }
 
 1;
