@@ -123,7 +123,7 @@ my @new_fields = qw(
     name type sticky sticky_value default_value action
     mandatory ajax_validates ajax_canonicalizes autocompleter preamble hints
     placeholder focus render_mode display_length max_length _element_id
-    disable_autocomplete multiple
+    disable_autocomplete multiple attributes
 );
 
 my @semiexposed_fields = qw(
@@ -216,6 +216,12 @@ aka. has multiple attribute, which is uselful for select field.
 For the purposes of L<Jifty::Web::Form::Element>, the unique id of
 this field is its input name.
 
+=head2 attributes
+
+If the field object is generated by L<Jifty::Action::Record>, this
+holds the additional attributes declared to the corresponding column
+of the model.
+
 =cut
 
 sub id {
@@ -395,6 +401,7 @@ sub render {
         $self->render_canonicalization_notes();
     } elsif ($self->render_mode eq 'read'){ 
         $self->render_value();
+        $self->render_preload_javascript();
     }
     $self->render_wrapper_end();
     return ('');
@@ -402,9 +409,9 @@ sub render {
 
 =head2 render_inline_javascript
 
-Render a <script> tag (if neceesary) containing any inline javascript
-that should follow this form field. This is used to add an
-autocompleter, placeholder, or keybinding to form fields where needed.
+Render a <script> tag (if necessary) containing any inline javascript that
+should follow this form field. This is used to add an autocompleter,
+placeholder, keybinding, or preloading to form fields where needed.
 
 =cut
 
@@ -419,7 +426,8 @@ sub render_inline_javascript {
             $self->autocomplete_javascript(),
             $self->placeholder_javascript(),
             $self->key_binding_javascript(),
-            $self->focus_javascript()
+            $self->focus_javascript(),
+            $self->preload_javascript(),
         )
     );
     
@@ -429,6 +437,24 @@ sub render_inline_javascript {
     }
 }
 
+=head2 render_preload_javascript
+
+Render a <script> tag (if necessary) containing any inline preload javascript
+that should follow this form field.
+
+=cut
+
+sub render_preload_javascript {
+    my $self = shift;
+
+    my $javascript = $self->preload_javascript;
+
+    if($javascript =~ /\S/) {
+        Jifty->web->out(qq{<script type="text/javascript">$javascript</script>
+});
+    }
+}
+
 =head2 classes
 
 Renders a default CSS class for each part of our widget.
@@ -647,7 +673,7 @@ sub render_autocomplete {
     my $self = shift;
     return unless $self->autocompleter;
     $self->render_autocomplete_div;
-    Jifty->web->out(qq{<script type="text/javascript">@{[$self->autocomplete_javascript]}</script>});
+    Jifty->web->out(qq!<script type="text/javascript">@{[$self->autocomplete_javascript]}</script>!);
     return '';
 }
 
@@ -663,7 +689,8 @@ call, if necessary.
 sub autocomplete_javascript {
     my $self = shift;
     return unless($self->autocompleter);
-    return qq{new Jifty.Autocompleter('@{[$self->element_id]}','@{[$self->element_id]}-autocomplete')};
+    my $element_id = $self->element_id;
+    return qq{new Jifty.Autocompleter('$element_id','$element_id-autocomplete')};
 }
 
 =head2 placeholder_javascript
@@ -681,7 +708,7 @@ sub placeholder_javascript {
     $placeholder =~ s{(['\\])}{\\$1}g;
     $placeholder =~ s{\n}{\\n}g;
     $placeholder =~ s{\r}{\\r}g;
-    return qq{new Jifty.Placeholder('@{[$self->element_id]}', '$placeholder');};
+    return qq!new Jifty.Placeholder('@{[$self->element_id]}', '$placeholder');!;
 }
 
 =head2 focus_javascript
@@ -695,11 +722,45 @@ sub focus_javascript {
     my $self = shift;
     return undef;
     if($self->focus) {
-        return qq{document.getElementById("@{[$self->element_id]}").focus()};
-        return qq{DOM.Events.addListener( window, "load", function(){document.getElementById("@{[$self->element_id]}").focus()})};
+        return qq!document.getElementById("@{[$self->element_id]}").focus()!;
+        return qq!DOM.Events.addListener( window, "load", function(){document.getElementById("@{[$self->element_id]}").focus()})!;
     }
 }
 
+=head2 preload_javascript
+
+Returns the javascript necessary to load regions that have been marked for
+preloading, as plain javascript. The L</javascript> method will look for
+regions marked with preloading and swap them in, instead of loading them
+directly.
+
+=cut
+
+sub preload_javascript {
+    my $self = shift;
+
+    my $structure = $self->_javascript_attrs_structure;
+    my @javascript;
+    for my $trigger (keys %$structure) {
+        my $trigger_structure = $structure->{$trigger};
+        next unless $trigger_structure->{preload_key};
+
+        my @preloaded;
+
+        my $preload_json = Jifty::JSON::objToJson(
+            {
+                fragments   => $trigger_structure->{fragments},
+                preload_key => $trigger_structure->{preload_key},
+            },
+            { singlequote => 1 },
+        );
+
+        push @javascript, "Jifty.preload($preload_json, this);";
+    }
+
+    return join "\n", @javascript;
+}
+
 =head2 render_hints
 
 Renders any hints for using this input.  Defaults to nothing, though
