@@ -16,6 +16,10 @@ function createCalendarLink(id) {
     return Jifty.Calendar.registerDateWidget( id );
 }
 
+function createDateTimeLink(id) {
+    return Jifty.DateTime.registerDateTimeWidget( id );
+}
+
 JSAN.use("DOM.Events");
 
 function buttonToLink(e) {
@@ -23,7 +27,7 @@ function buttonToLink(e) {
     link.setAttribute("href","#");
     link.setAttribute("name",e.getAttribute("name"));
 
-    var form = Form.Element.getForm(e);
+    var form = Jifty.Form.Element.getForm(e);
     var onclick = e.getAttribute("onclick");
 
     /* Simple buttons that don't use any JS need us to create an onclick
@@ -43,6 +47,7 @@ function buttonToLink(e) {
         });
     }
     link.setAttribute("onclick", onclick);
+    link.setAttribute("title", e.getAttribute("title"));
 
     link.className = e.className;
     link["virtualform"] = form;
