@@ -19,6 +19,10 @@ use Jifty::Action schema {
         ajax validates,
         valid are qw(happy angry normal);
 
+    param flavor =>
+        autocompleter is \&autocomplete_flavor,
+        type is 'text';
+
     param tags =>
         type is 'text',
         ajax canonicalizes;
@@ -54,5 +58,13 @@ sub canonicalize_tags {
     return $v;
 }
 
+sub autocomplete_flavor {
+    my ($self, $value) = @_;
+    return grep {
+        $_ =~ /$value/i;
+    } sort qw( berry vanilla caramel caracara honey miso blueberry strawberry );
+
+}
+
 1;
 
