@@ -5,6 +5,9 @@ package TestApp::Plugin::REST::Model::Group;
 use Jifty::DBI::Schema;
 
 use TestApp::Plugin::REST::Record schema {
+column 'name' =>
+  type is 'text',
+  is mandatory;
 
 };
 
