@@ -1,9 +1,12 @@
-package TestApp::Plugin::REST::Model::User::Schema;
+package TestApp::Plugin::REST::Model::User;
+use base qw/TestApp::Plugin::REST::Record/;
+
 use Jifty::DBI::Schema;
 
 # Your column definitions go here.  See L<Jifty::DBI::Schema> for
 # documentation about how to write column definitions.
 
+use Jifty::Record schema {
 column 'name' =>
   type is 'text',
   is mandatory;
@@ -13,11 +16,9 @@ column 'email' =>
 column 'tasty' =>
   type is 'boolean',
   is immutable;
+};
 
 
-package TestApp::Plugin::REST::Model::User;
-use base qw/TestApp::Plugin::REST::Record/;
-
 # Your model-specific methods go here.
 
 1;
